local addonName, addonTable = ...
local Options = CreateFrame("Frame", "GoodmanUIOptions", InterfaceOptionsPanelContainer)
Options.name = addonName
InterfaceOptions_AddCategory(Options)
Options:Hide()

local function createCheckbox(label, description, x, y, pointParent, parent, checked, onClick)
    local checkbox = CreateFrame("CheckButton", nil, parent, "InterfaceOptionsCheckButtonTemplate")
    checkbox:SetPoint("TOPLEFT", pointParent, "BOTTOMLEFT", x, y)
    checkbox.label = parent:CreateFontString(nil, "ARTWORK", "GameFontNormal")
    checkbox.label:SetPoint("LEFT", checkbox, "RIGHT", 0, 0)
    checkbox.label:SetText(label)
    checkbox.tooltipText = label
    checkbox.tooltipRequirement = description
    checkbox:SetChecked(checked)
    checkbox:SetScript("OnClick", onClick)
    return checkbox
end

-- local function createSlider(name, parent, low, high, label, description)
--     local Slider = CreateFrame("Slider", name, parent, "OptionsSliderTemplate")
--     Slider:SetWidth(180)
--     Slider:SetObeyStepOnDrag(true)
--     Slider.label = parent:CreateFontString(nil, "ARTWORK", "GameFontNormal")
--     Slider.label:SetPoint("TOP", Slider, "BOTTOM", 0, 0)
--     Slider.label:SetText(label)
--     Slider.low = _G[Slider:GetName() .. "Low"]
--     Slider.low:SetPoint("TOPLEFT", Slider, "BOTTOMLEFT", 0, 0)
--     Slider.low:SetFontObject(GameFontNormalSmall)
--     Slider.low:SetText(low)
--     Slider.high = _G[Slider:GetName() .. "High"]
--     Slider.high:SetPoint("TOPRIGHT", Slider, "BOTTOMRIGHT", 0, 0)
--     Slider.high:SetFontObject(GameFontNormalSmall)
--     Slider.high:SetText(high)
--     Slider.value = Slider:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
--     Slider.value:SetPoint("BOTTOM", Slider, "TOP")
--     Slider:SetMinMaxValues(low, high)
--     Slider.tooltipText = label
--     Slider.tooltipRequirement = description
--     return Slider
-- end

local function createButton(text, x, y, pointParent, parent, width, height, onClick)
    local Button = CreateFrame("Button", nil, parent, "UIPanelButtonTemplate")
    Button:SetPoint("TOPLEFT", pointParent, "BOTTOMLEFT", x, y)
    Button:SetWidth(width)
    Button:SetHeight(height)
    Button:SetText(text)
    Button:SetScript("OnClick", onClick)
    return Button
end

-- local function createText(text, pointParent, parent, x, y)
--     local Text = parent:CreateFontString(nil, parent, "GameFontNormalLarge")
--     Text:SetPoint("TOPLEFT", pointParent, "BOTTOMLEFT", x, y)
--     Text:SetText(text)
--     return Text
-- end

-- local function createCategory(name, categoryConstructor)
--     local CategoryFrame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
--     CategoryFrame.name = name
--     CategoryFrame.parent = addonName
--     InterfaceOptions_AddCategory(CategoryFrame, addonName)
--     CategoryFrame:Hide()
--     CategoryFrame:SetScript(
--         "OnShow",
--         function(self)
--             local title = CategoryFrame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
--             title:SetPoint("TOPLEFT", 16, -16)
--             title:SetText(addonName .. " - " .. name)
--             local SubText = CategoryFrame:CreateFontString("$parentSubText", "ARTWORK", "GameFontHighlightSmall")
--             SubText:SetPoint("TOPLEFT", title, "BOTTOMLEFT", -2, -16)
--             categoryConstructor(CategoryFrame, SubText)
--             OkayGo:Show()
--             self:SetScript(
--                 "OnHide",
--                 function()
--                     OkayGo:Hide()
--                 end
--             )
--             self:SetScript(
--                 "OnShow",
--                 function()
--                     OkayGo:Show()
--                 end
--             )
--         end
--     )
-- end

-- Default section
Options:SetScript(
    "OnShow",
    function(self)
        local title = Options:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
        title:SetPoint("TOPLEFT", 16, -16)
        title:SetText(addonName)
        local SubText = Options:CreateFontString("$parentSubText", "ARTWORK", "GameFontHighlightSmall")
        SubText:SetPoint("TOPLEFT", title, "BOTTOMLEFT", -2, -16)
        SubText:SetText(GetAddOnMetadata(addonName, "Notes"))

        local LUA_ERRORS =
        createCheckbox(
        "LUA errors",
        "Show LUA script errors",
        0,
        -16,
        SubText,
        Options,
        GoodmanUIDB.GENERAL.LUA_ERRORS,
        function(self)
            GoodmanUIDB.GENERAL.LUA_ERRORS = self:GetChecked()
        end
        )

        local SELL_JUNK =
        createCheckbox(
        "Sell junk",
        "Automatically sell gray items when vendor tab is open",
        0,
        -16,
        LUA_ERRORS,
        Options,
        GoodmanUIDB.AUTOMATION.SELL_JUNK,
        function(self)
            GoodmanUIDB.AUTOMATION.SELL_JUNK = self:GetChecked()
        end
        )

        local HIDE_HOTKEYS =
        createCheckbox(
        "Hide hotkeys",
        "",
        0,
        -16,
        SELL_JUNK,
        Options,
        GoodmanUIDB.ACTIONBARS.HIDE_HOTKEYS,
        function(self)
            GoodmanUIDB.ACTIONBARS.HIDE_HOTKEYS = self:GetChecked()
        end
        )

        local HIDE_MACRONAMES =
        createCheckbox(
        "Hide macros names",
        "",
        0,
        -16,
        HIDE_HOTKEYS,
        Options,
        GoodmanUIDB.ACTIONBARS.HIDE_MACRONAMES,
        function(self)
            GoodmanUIDB.ACTIONBARS.HIDE_MACRONAMES = self:GetChecked()
        end
        )
        
        local HIDE_GRYPHONS =
        createCheckbox(
        "Hide gryphons",
        "Hide Mainbar gryphons art",
        0,
        -16,
        HIDE_MACRONAMES,
        Options,
        GoodmanUIDB.ACTIONBARS.HIDE_GRYPHONS,
        function(self)
            GoodmanUIDB.ACTIONBARS.HIDE_GRYPHONS = self:GetChecked()
        end
        )
      
        local RAIDFRAMES_SOLO  =
            createCheckbox(
            "Show Raid frames when solo",
            "",
            0,
            -24,
            HIDE_GRYPHONS,
            Options,
            GoodmanUIDB.RAIDFRAMES.SOLO,
            function(self)
                GoodmanUIDB.RAIDFRAMES.SOLO = self:GetChecked()
            end
        )

        createButton("Reload UI", 540, 40, Options, Options, 100, 25,
        function() 
            ReloadUI()
        end
        );
    end
)